@@ -7,16 +7,17 @@ def SampleCurves(sample, N=500):
     deviation of the samples. For input, the function requires "sample" to be a callable object which
     returns randomly sampled Curve objects.
     """
-    assert( N >= 2 )
-    SUM = Curve([(0,0), (1,1)])
+    assert( N >= 1 )
+    assert( type(N) == int )
+    SUM = Curve([(0,0), (1,0)])
     AREA = []
-    for i in xrange(sample):
-        C = F(S.sweep_threshold_random())
+    for i in xrange(N):
+        C = sample()
         SUM += C
         AREA.append(C.area())
     curve = SUM.vertical_scale(1.0 / N)
     average = reduce(lambda a,b:a+b, AREA) / N
-    std_devation = reduce(lambda a,b:a+b, ((x - average) ** 2 for x in AREA) ) / ( N - 1 )
+    std_deviation = reduce(lambda a,b:a+b, ((x - average) ** 2 for x in AREA) ) / ( N - 1 )
     return curve, average, std_deviation
 
 def BEDROC(scoreddata, alpha):
